
use strict;
use warnings;
use utf8;
use Test::More;
use File::Which qw/which/;
use Parse::Crontab;
# 11 2 * * * $MYPROJ_RUN script/batch.pl
# DailyPartition 2>&1 | $LOGGER cron.daily_partition -
# 上記のように指定されているか確認する

my $crontab = Parse::Crontab->new(
  file => 'data/crontab.txt'
);
# crontabのシンタックスに誤りがないかを確認する
ok $crontab->is_valid
    or diag $crontab->error_messages;

# うっかりした毎分指定や、日付と曜日の
# 重複指定などの間違いの可能性のある項目を確認する
ok !$crontab->warning_messages
  or diag $crontab->warning_messages;

# ジョブ一覧を取得する
for my $job ($crontab->jobs) {
  my $command = $job->command;
  # ちゃんと$LOGGERでログを出力しているか
  like $command, qr!2>&1\s+\|\s+\$LOGGER!, 'logger ok';

  # $MYPROJ_RUN を噛まして起動する規約を守っているか
  ok $command =~ m!^\$MYPROJ_RUN!;
  my ($opt, $rest_command) =
    $command =~
      m!^\$MYPROJ_RUN\s*(.*?)?\s*--\s*(.*)!;

  # 実行権がちゃんと付与されているか
  my $cmd = +(split /\s+/, $rest_command)[0];
  ok -e $cmd or $cmd = which($cmd);
  ok -x $cmd;
  if (my ($module) =
    $rest_command =~
      m!^script/batch\.pl\s+([A-Za-z0-9]+)!
  ) {
    # batch.plを使っている場合、指定している
    # モジュールが存在するかテストする
    my $module_file = "lib/MyApp/Batch/$module.pm";
    ok -e $module_file;
  }
  # スケジュールオブジェクトを取り出して
  # 必要におじて実行時間のテストをする
  my $schedule = $job->schedule;
  #ok $schedule->match(hour => 2, minutes => 15);
};
done_testing;
